PredictionErrorMechanism
========================

.. automodule:: psyneulink.library.components.mechanisms.processing.objective.predictionerrormechanism
   :members:
   :private-members:
   :exclude-members: Parameters